@@ -195,7 +195,10 @@ async fn test_properties() -> Result<()> {
     // FIXME: Use a real stable page
     let code = client.get("User:Legoktm/archive.txt").await?;
     assert_eq!(code.revision_id(), Some(2016428));
-    assert_eq!(code.title(), Some("User:Legoktm/archive.txt".to_string()));
+    assert_eq!(
+        code.get_title(),
+        Some("User:Legoktm/archive.txt".to_string())
+    );
     Ok(())
 }
 
@@ -221,7 +224,7 @@ async fn test_iterators() -> Result<()> {
 async fn test_title() -> Result<()> {
     let client = build_client();
     let code = client.get("Project:Requests").await?;
-    assert_eq!(code.title().unwrap(), "Project:Requests".to_string());
+    assert_eq!(code.get_title().unwrap(), "Project:Requests".to_string());
     Ok(())
 }
 
@@ -622,3 +625,11 @@ async fn test_indicator() -> Result<()> {
     );
     Ok(())
 }
+
+#[tokio::test]
+async fn test_spec_version() -> Result<()> {
+    let client = build_client();
+    let code = client.get("Main Page").await?;
+    assert_eq!(&code.spec_version().unwrap(), "2.3.0");
+    Ok(())
+}
